Pets Best Customer Portal Login

Pets Best Insurance. Simply the best pet insurance. Pet Insurance for Dogs and Cats
1-877-738-7237
Underwriting Information

## Your Account

- Remember me
- Forgot password?

## Not Yet Registered?

Create your account to:

- Add a new pet to your policy
- Submit or update claims
- Check claim status
- View your plan details
- Sign up for direct deposit

Register

### Need Help?

Call Pets Best Customer Care

- 1-877-738-7237 ext. 1
- 8 AM - 5 PM Monday - Friday
- 10 AM - 2 PM Saturday
- Mountain Time

Live Chat
If you enrolled your pet online, you already have a Customer Account.

- Your username is the email address you used to enroll your pet
- Your password is the one you chose when you enrolled

If you enrolled your pet by phone, it’s easy to activate your Customer Account.

- Click the “Register” button on the left
- Have your email address or policy number handy

## Get Reimbursed Faster

Direct deposit is the fastest, easiest way to get reimbursed, and it’s free for all policyholders! Simply log in and click “Personal & Payment Info”.